from django.db import connection, migrations


class Migration(migrations.Migration):
    dependencies = [
        ("nautobot_device_lifecycle_mgmt", "0015_role_migration"),
    ]

    nautobot_run_before = [("dcim", "0031_remove_device_role_and_rack_role")]

    operations = [
        migrations.RemoveField(
            model_name="validatedsoftwarelcm",
            name="legacy_roles",
        ),
        migrations.RenameField(
            model_name="validatedsoftwarelcm",
            old_name="new_roles",
            new_name="device_roles",
        ),
    ]

    def __init__(self, name, app_label):
        """
        Override the default __init__ method to conditionally set the run_before attribute based on whether
        the first squashed migration has already been applied. This is necessary to ensure that the depdendency
        graph generated by Django does not fail due to a circular dependency.
        """
        super().__init__(name, app_label)
        if self.nautobot_run_before:
            recorder = migrations.recorder.MigrationRecorder(connection)
            applied_migrations = recorder.applied_migrations()
            if ("nautobot_device_onboarding", "0004_validated_software_m2m") in applied_migrations:
                for migration in self.nautobot_run_before:
                    if migration not in applied_migrations:
                        self.run_before.append(migration)
